@@ -2,11 +2,12 @@ package Data::Record::Serialize::Role::Encode;
 
 # ABSTRACT: Encode Role
 
+use v5.12;
 use Moo::Role;
 
 use namespace::clean;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 requires 'encode';
 
@@ -34,18 +35,20 @@ Data::Record::Serialize::Role::Encode - Encode Role
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 DESCRIPTION
 
 If a role consumes this, it signals that it provides encoding
 capabilities.
 
+=head1 INTERNALS
+
 =head1 SUPPORT
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>
 
 =head2 Source
 
