@@ -2,11 +2,12 @@ package Data::Record::Serialize::Role::Sink;
 
 # ABSTRACT: Sink Role
 
+use v5.12;
 use Moo::Role;
 
 use namespace::clean;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 requires 'print';
 requires 'say';
@@ -51,7 +52,7 @@ Data::Record::Serialize::Role::Sink - Sink Role
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 DESCRIPTION
 
@@ -71,11 +72,13 @@ it is quite possible that it will not be possible to perform this
 cleanly.  In other words, make sure that sinks are closed prior to
 global destruction.
 
+=head1 INTERNALS
+
 =head1 SUPPORT
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>
 
 =head2 Source
 
