@@ -2,12 +2,12 @@ package Data::Record::Serialize::Sink::array;
 
 # ABSTRACT: append encoded data to an array.
 
-
+use v5.12;
 use Moo::Role;
 
-use Data::Record::Serialize::Error { errors => [ '::create' ] }, -all;
+use Data::Record::Serialize::Error { errors => ['::create'] }, -all;
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 use IO::File;
 
@@ -24,9 +24,9 @@ use namespace::clean;
 
 
 has output => (
-               is      => 'ro',
-               clearer => 1,
-               default => sub { [] },
+    is      => 'ro',
+    clearer => 1,
+    default => sub { [] },
 );
 
 
@@ -36,9 +36,9 @@ has output => (
 
 
 
-sub print { push @{shift->{output}}, @_ }
+sub print { push @{ shift->{output} }, @_ }
 *say = \&print;
-sub close {}
+sub close { }
 
 with 'Data::Record::Serialize::Role::Sink';
 
@@ -66,7 +66,7 @@ Data::Record::Serialize::Sink::array - append encoded data to an array.
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
@@ -85,7 +85,7 @@ B<Data::Record::Serialize::Sink::sink> appends encoded data to an array.
 
 It performs the L<Data::Record::Serialize::Role::Sink> role.
 
-=head1 ATTRIBUTES
+=head1 OBJECT ATTRIBUTES
 
 =head2 output
 
@@ -95,6 +95,8 @@ The array into which the encoded record is stored.  The last record sent is at
 
    $s->output->[-1]
 
+=head1 INTERNALS
+
 =for Pod::Coverage print
  say
  close
@@ -113,7 +115,7 @@ Optional. Where to write the data. An arrayref is provided if not specified.
 
 =head2 Bugs
 
-Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize
+Please report any bugs or feature requests to bug-data-record-serialize@rt.cpan.org  or through the web interface at: L<https://rt.cpan.org/Public/Dist/Display.html?Name=Data-Record-Serialize>
 
 =head2 Source
 
